@@ -1,6 +1,6 @@
 import os
 import abc
-
+import pathlib
 """
 
 python 中引入给文件加锁的 fcntl模块
@@ -90,8 +90,8 @@ if __name__ == '__main__':
     import nb_log
     import time
 
-    print('等待获得锁')
-    with FileLock('testx.lock'):
+    print('wait for lock')
+    with FileLock(pathlib.Path(__file__).parent/pathlib.Path('testx.lock')):
         print('hi')
         time.sleep(20)
         print('hello')
